@@ -11,45 +11,25 @@ Mnet::Opts::Cli - Define and parse command line options
 
     # define --sample cli option
     Mnet::Opts::Cli::define({
-        getopt      => "sample=s",
-        default     => "",
-        help_tip    => "set to input string",
-        help_text   => "
-            use --sample to set an input string
-            refer to perldoc for more information
-        ",
+        getopt   => "sample=s",
+        help_tip => "set to input string",
     });
 
-    # optional environment variable can also be parsed for options
-    my $env = "Mnet";
-
     # call in list context for cli opts object and any extra args
-    my ($cli, @extras) = Mnet::Opts::Cli->new($env);
+    my ($cli, @extras) = Mnet::Opts::Cli->new();
 
     # call in scalar context to disallow extra args
-    $cli = Mnet::Opts::Cli->new($env);
+    $cli = Mnet::Opts::Cli->new();
 
     # access parsed cli options using method calls
     my $value = $cli->sample;
 
 =head1 DESCRIPTIONS
 
-Mnet::Opts::Cli can be used by scripts to define and parse command line
-options, as shown in the example above.
+The functions and methods in this module can be used by scripts to define and
+parse command line options, as shown in the example below:
 
-An optional environment variable can be used to set options, as shown in the
-example above.  This can be to secure passwords so they don't appear in system
-process table, as below:
-
-    export Mnet="--password secret"
-    script.pl
-
-Note that the specified environment variable is not parsed if the --test option
-is set on the command line. Refer to L<Mnet::Test> for more information.
-
-=head1 METHODS
-
-Mnet::Opts::Cli implements the methods listed below.
+Refer to the Mnet::Opts and Mnet::Opts::Cli::Cache modules for more info.
 
 =cut
 
@@ -86,19 +66,21 @@ INIT {
     if ($INC{"Mnet/Tee.pm"}) {
         $stdout = $Mnet::Tee::stdout;
     } else {
-        open($stdout, ">&STDOUT") or die "error duping stdout, $!";
+        open($stdout, ">&STDOUT");
     }
 
     # define --help cli option
     Mnet::Opts::Cli::define({
         getopt      => 'help:s',
-        help_tip    => 'display option help, *try --help help',
+        help_tip    => 'display tips, or matching option text',
+        norecord    => 1,
     });
 
     # define --version cli option
     Mnet::Opts::Cli::define({
         getopt      => 'version',
         help_tip    => 'display version and system information',
+        norecord    => 1,
     });
 
 # finished init code block
@@ -126,7 +108,7 @@ letter and contain only letters, numbers, and the dash character. Dashes are
 replaced with underscores after the options are parsed, so they may be referred
 to more easily in script code.
 
-The following L<Getopt::Long> option specification types are supported:
+The following Getopt::Long option specification types are supported:
 
     opt    --opt       boolean option, set true if --opt is set
     opt!   --[no]opt   negatable option, returns false if --noopt is set
@@ -139,13 +121,12 @@ The following keys in the specs input hash reference argument are supported:
 
     getopt      required option name and type, see perldoc Getopt::Long
     default     default value for option, defaults to undefined
-    help_hide   set to hide option in --help list of available options
     help_tip    short tip text for --help list of available options
     help_text   longer help text to show in --help for specific options
-    record      set so option is saved in Mnet::Test record/replay files
-    redact      set to prevent option value showing in Mnet::Log output
+    norecord    set so option is not saved to Mnet::Test record/replay
+    redact      set to revent option value from displaying in Mnet::Log
 
-Refer to L<Getopt::Long> for more information.
+Refer to perldoc Getopt::Long for more information.
 
 =cut
 
@@ -155,8 +136,8 @@ Refer to L<Getopt::Long> for more information.
 
     # check for required getopt key in input specs, note opt name
     croak("missing specs hash getopt key") if not defined $specs->{getopt};
-    croak("invalid specs hash getopt value $specs->{getopt}")
-        if $specs->{getopt} !~ /^([a-z0-9](-|[a-z0-9])*)(!|=i|:i|=s|:s)?$/;
+    croak("invalid specs hash getopt value")
+        if $specs->{getopt} !~ /^([a-z][-a-z0-9]+)/;
     my $opt = $1;
 
     # abort if option was already defined
@@ -170,13 +151,6 @@ Refer to L<Getopt::Long> for more information.
     # set caller for defined option
     $Mnet::Opts::Cli::defined->{$opt}->{caller} = caller;
 
-    # set default help_tip if not defined
-    if (not defined $Mnet::Opts::Cli::defined->{$opt}->{help_text}) {
-        my $caller = $Mnet::Opts::Cli::defined->{$opt}->{caller};
-        my $text = "option defined by caller $caller, no help_text was set";
-        $Mnet::Opts::Cli::defined->{$opt}->{help_text} = $text;
-    }
-
     # set help_usage for defined option
     #   note that this aborts with an error for unsupported Getopt::Long types
     $Mnet::Opts::Cli::defined->{$opt}->{help_usage}
@@ -221,15 +195,12 @@ sub new {
 
 =head2 new
 
-    $opts = Mnet::Opts::Cli->new($env_var)
-    or ($cli, @extras) = Mnet::Opts::Cli->new($env_var)
+    $opts = Mnet::Opts::Cli->new()
+    or ($cli, @extras) = Mnet::Opts::Cli->new()
 
-The new class method may be used to retrieve an options object containing
-defined options parsed from the command line and an array contining any extra
-command line arguments.
-
-The env_var argument is optional, and can be set to the name of an environment
-variable where additional command line options can be securely set.
+The class method may be used to retrieve an options object containing defined
+options parsed from the command line and an array contining any extra command
+line arguments.
 
 If called in list context this method will return an opts object containing
 values for defined options parsed from the command line followed by a list of
@@ -238,7 +209,7 @@ any other extra arguments that were present on the command line.
     use Mnet::Opts::Cli;
     my ($cli, @extras) = Mnet::Opts::Cli->new();
 
-If not called in list context an error will be issued if extra command line
+If called in scalar context an error will be issued if extra command line
 arguments exist.
 
     use Mnet::Opts::Cli;
@@ -249,22 +220,20 @@ Options are applied in the following order:
     child Mnet::Batch command lines
     command line
     replayed command line
-    optional environment variable
+    Mnet environment variable
     Mnet::Opts::Set use pragmas
     Mnet::Opts::Cli::define default key
 
 Note that errors are not issued for unknown options that may be set for other
-scripts in the optional env_var environment variable. Also note that this
-environment variable is not parsed if the --test option is set on the command
-line.
+scripts in the Mnet environment variable. Also note that the Mnet environment
+variable is not parsed if the --test option is set on the command line.
 
 The perl ARGV array is not modified by this module.
 
 =cut
 
-    # read input class and optional envrionement variable name
+    # read input class
     my $class = shift // croak("missing class arg");
-    my $env_var = shift;
 
     # read batch child opts from Mnet::Opts::Cli::batch() only
     #   refer to Mnet::Opts::Cli::batch() for more information
@@ -374,13 +343,13 @@ The perl ARGV array is not modified by this module.
 
     # parse options from --replay file only if --test is also set
     #   force a re-read of the --replay file for forked batch children
-    #   ignore --replay file options that weren't defined with record set
+    #   ignore --replay file options that were defined norecord key set
     my $replay_opts = {};
     if (defined $cli_opts->{replay}) {
         my $test_data_opts = { replay => $cli_opts->{replay} };
         my $test_data = Mnet::Test::data($test_data_opts, "force");
         foreach my $opt (sort keys %{$Mnet::Opts::Cli::defined}) {
-            next if not $Mnet::Opts::Cli::defined->{$opt}->{record};
+            next if $Mnet::Opts::Cli::defined->{$opt}->{norecord};
             next if not exists $test_data->{opts}->{$opt};
             $replay_opts->{$opt} = $test_data->{opts}->{$opt};
             my $opt_dump = Mnet::Dump::line($replay_opts->{$opt});
@@ -388,16 +357,16 @@ The perl ARGV array is not modified by this module.
         }
     }
 
-    # parse options from env_var if --test/record/replay opts are not set
+    # parse options from Mnet env var if --test/record/replay opts are not set
     #   ignore warnings for env options that might not be defined at the moment
     my $env_opts = {};
-    if (defined $env_var and defined $ENV{$env_var}
+    if (defined $ENV{Mnet}
         and not defined $cli_opts->{replay}
         and not defined $cli_opts->{record}) {
         eval {
             local $SIG{__WARN__} = "IGNORE";
             Getopt::Long::GetOptionsFromString(
-                $ENV{$env_var}, $env_opts, @definitions
+                $ENV{Mnet}, $env_opts, @definitions
             );
         }
     }
@@ -414,8 +383,8 @@ The perl ARGV array is not modified by this module.
     foreach my $opt (sort keys %{$Mnet::Opts::Cli::defined}) {
         my $defined_opt = $Mnet::Opts::Cli::defined->{$opt};
 
-        # options can be reset with --test-reset cli option
-        if ($cli_opts->{'test-reset'} and $cli_opts->{'test-reset'} eq $opt) {
+        # options can be reset to with --reset cli option
+        if ($cli_opts->{reset} and $cli_opts->{reset} eq $opt) {
             $log_entries->{$opt} = "def";
             $opts->{$opt} = $defined_opt->{default};
 
@@ -468,13 +437,12 @@ The perl ARGV array is not modified by this module.
     #   log_entries keys are opt names, set to source keyword followed by dump
     #   default opts identified with 'def' log entry prefix are logged to debug
     #   notice entries used for opts that would interfere with Mnet::Test diffs
-    #       so that opts without record set are not saved in --record file logs
     foreach my $opt (sort keys %$log_entries) {
         my $log_entry = $log_entries->{$opt};
         $log_entry =~ s/(\S+)/opt $1 ${opt} =/;
         if ($log_entry =~ /^opt def/) {
             $log->debug("new parsed $log_entry");
-        } elsif (not $Mnet::Opts::Cli::defined->{$opt}->{record}
+        } elsif ($Mnet::Opts::Cli::defined->{$opt}->{norecord}
             and ($opts->{replay} or $opts->{record}
             or $opts->{batch})) {
             $log->notice("new parsed $log_entry");
@@ -484,7 +452,7 @@ The perl ARGV array is not modified by this module.
     }
 
     # output extra cli arg error when not called to return extras args
-    die "invalid or missing args @extras\n" if $extras[0] and not wantarray;
+    die "invalid extra args @extras\n" if $extras[0] and not wantarray;
 
     # get test data hash ref from Mnet::Test module
     #   init to empty dummy hash ref if Mnet::Test not loaded
@@ -492,10 +460,10 @@ The perl ARGV array is not modified by this module.
     $test_data = Mnet::Test::data() if $INC{"Mnet/Test.pm"};
 
     # update opts in test in case --record will be used later
-    #   skip opts that were defined without the record key enabled
+    #   skip opts that were defined with the norecord key enabled
     $test_data->{opts} = {};
     foreach my $opt (sort keys %$opts) {
-        next if not $Mnet::Opts::Cli::defined->{$opt}->{record};
+        next if $Mnet::Opts::Cli::defined->{$opt}->{norecord};
         my $value = $opts->{$opt};
         my $default = $Mnet::Opts::Cli::defined->{$opt}->{default};
         next if not defined $value and not defined $default;
@@ -509,8 +477,8 @@ The perl ARGV array is not modified by this module.
     if (defined $extras[0]) {
         $log->debug("new extra cli args will record from command line");
         $test_data->{extras} = \@extras;
-    } elsif (defined $opts->{'test-reset'} and $opts->{'test-reset'} eq ""){
-        $log->debug("new extra cli args will reset via --test-reset");
+    } elsif (defined $opts->{reset} and $opts->{reset} eq "") {
+        $log->debug("new extra cli args will record as reset to --reset");
         delete $test_data->{extras};
     } elsif (exists $test_data->{extras}) {
         $log->debug("new extra cli args will replay from Mnet::Test data");
@@ -522,7 +490,6 @@ The perl ARGV array is not modified by this module.
         foreach @extras;
 
     # change opt names that have a dash to an underscore
-    #   i.e $opts->{opt_name} instead of $opts->{'opt-name'}
     foreach my $opt (sort keys %$opts) {
         next if $opt !~ /-/;
         my $value = $opts->{$opt};
@@ -534,10 +501,7 @@ The perl ARGV array is not modified by this module.
     # update cli opt cache for the final time, including extra cli args
     Mnet::Opts::Cli::Cache::set($opts, @extras);
 
-    # disable --debug-error in Mnet::Log if not set on cli, to save memory
-    Mnet::Log::disable_debug_error()
-        if $INC{'Mnet/Log.pm'} and not $opts->{debug_error};
-
+    # create new cli opts object using the current class
     my $self = bless $opts, $class;
 
     # finished new method, return cli opts object and extra args or just opts
@@ -561,7 +525,7 @@ sub _new_help {
     my $output = "\n";
 
     # output list of help usage tips, one line per option
-    if ($help eq "" or $help eq "help") {
+    if ($help eq "") {
 
         # calculate width to align usage and tip columns
         my $width = 0;
@@ -576,7 +540,6 @@ sub _new_help {
             my ($width, $defined_opt) = (shift, shift);
             my $usage = $defined_opt->{help_usage};
             my $tip = $defined_opt->{help_tip} // "";
-            $tip = "*$tip" if $defined_opt->{help_hide};
             return sprintf(" --%-${width}s   $tip\n", $usage);
         }
 
@@ -584,7 +547,6 @@ sub _new_help {
         my $other_options = "";
         foreach my $opt (sort keys %{$Mnet::Opts::Cli::defined}) {
             my $defined_opt = $Mnet::Opts::Cli::defined->{$opt};
-            next if $help ne "help" and $defined_opt->{help_hide};
             next if $defined_opt->{caller} =~ /^Mnet(::|$)/;
             $other_options = "Script options:\n\n" if not $other_options;
             $other_options .= _new_help_tip($width, $defined_opt);
@@ -592,10 +554,9 @@ sub _new_help {
         $output .= "$other_options\n" if $other_options;
 
         # output Mnet options
-        $output .= "Other options:\n\n";
+        $output .= "Mnet options:\n\n";
         foreach my $opt (sort keys %{$Mnet::Opts::Cli::defined}) {
             my $defined_opt = $Mnet::Opts::Cli::defined->{$opt};
-            next if $help ne "help" and $defined_opt->{help_hide};
             next if $defined_opt->{caller} !~ /^Mnet(::|$)/;
             $output .= _new_help_tip($width, $defined_opt);
         }
@@ -608,7 +569,7 @@ sub _new_help {
             my $defined_opt = $Mnet::Opts::Cli::defined->{$opt};
 
             # skip option names that don't match input --help text
-            next if $opt !~ /^\Q$help\E$/;
+            next if $opt !~ /^\Q$help\E/;
 
             # output usage for current command
             my $usage = $defined_opt->{help_usage};
@@ -616,7 +577,7 @@ sub _new_help {
 
             # output if option is saved in --record files
             my $recordable = "\n";
-            $recordable = "   (recordable)\n" if $defined_opt->{record};
+            $recordable = "   (recordable)\n" if not $defined_opt->{norecord};
             $output .= $recordable;
 
             # output tip for current command, if defined
@@ -668,11 +629,10 @@ sub batch_fork {
     # finished Mnet::Opts::Cli::batch, return child_opts and child_extras
     #   what is returned depends on context Mnet::Batch::fork() was called
     if (wantarray) {
-        my ($child_opts, @child_extras)
-            = Mnet::Opts::Cli->new(undef, $batch_argv);
+        my ($child_opts, @child_extras) = Mnet::Opts::Cli->new($batch_argv);
         return ($child_opts, @child_extras);
     } else {
-        my $child_opts = Mnet::Opts::Cli->new(undef, $batch_argv);
+        my $child_opts = Mnet::Opts::Cli->new($batch_argv);
         return $child_opts;
     }
 }
@@ -681,20 +641,20 @@ sub batch_fork {
 
 =head1 TESTING
 
-When used with the L<Mnet::Test> --record option this module will save all
-cli options to the specified file if they were defined with the record option
-attribute set true. Any extra arguments specified on the command line will also
-be saved. For more info about enabling the recording of individual options
-refer to the define function in this module and the --test-reset option.
+When used with the Mnet::Test --record option this module will save all cli
+options defined without the norecord hash key set true in the specified file
+along with any extra arguments specified on the command line. For more info
+about enabling the recording of individual options refer to the define
+function in this module and the --reset option.
 
 When the --replay option is used this module will load all cli options saved
 in the specified Mnet::Test file then apply options specified on the command
 line on top of the replayed options.
 
-When the --replay option is used for an L<Mnet::Test> file which was recorded
-with extra arguments the extra arguments from the replay file will be used
-unless there were extra arguments on the command line, in which case the
-command line arguments will replace the arguments read from the replay file.
+When the --replay option is used for an Mnet::Test file which was recorded with
+extra arguments the extra arguments from the replay file will be used unless
+there were extra arguments on the command line, in which case the command
+line arguments will replace the arguments read from the replay file.
 
 The --record option can be used to re-save the current --replay file after
 applying new command line options and/or extra arguments.
@@ -705,7 +665,9 @@ L<Getopt::Long>
 
 L<Mnet>
 
-L<Mnet::Opts>
+L<Mnet::Opts::Cli::Cache>
+
+L<Mnet::Opts::Set>
 
 L<Mnet::Test>
 
